@@ -48,13 +48,12 @@ from logging import DEBUG, Handler, getLogger
 from time import sleep
 from types import TracebackType  # noqa: F401
 from typing import (  # noqa: F401
-    IO, Any, Callable, Dict, Iterable, Iterator, List, Optional, Sequence, Set, Text, Tuple, Type, Union,
+    IO, Any, Callable, Dict, Iterable, Iterator, List, Optional, Sequence, Set, Tuple, Type, Union,
 )
 
 import apt
 import apt.progress
 import apt_pkg
-import six
 from apt.cache import FetchFailedException, LockFailedException, ProblemResolver
 
 from univention.lib.i18n import Translation
@@ -330,7 +329,7 @@ class DpkgProgress(apt.progress.base.InstallProgress):
 
                 # we got a new line -> send to info handler
                 self.progress_state.info(output.strip(), logger_name='process')
-            except (OSError, IOError):
+            except OSError:
                 # something unexpected happened -> break loop
                 break
 
@@ -424,7 +423,7 @@ class PackageManager(object):
 
     def __init__(self, lock=True, info_handler=None, step_handler=None, error_handler=None, always_noninteractive=True):
         # type: (bool, Optional[Callable[..., None]], Optional[Callable[..., None]], Optional[Callable[..., None]], bool) -> None
-        self.lock_fd = None  # type: Optional[IO[Text]]
+        self.lock_fd = None  # type: Optional[IO[str]]
         self.apt_lock_fd = -1  # type: int
         # parent logger, public. should be extended by adding a handler
         self.logger = getLogger('packagemanager')
@@ -764,8 +763,7 @@ class PackageManager(object):
         """
         if reopen:
             self.reopen_cache()
-        for pkg in self.cache:
-            yield pkg
+        yield from self.cache
 
     def mark_auto(self, auto, *pkgs):
         # type: (bool, PkgNameOrApt) -> None
@@ -821,7 +819,6 @@ class PackageManager(object):
                 fixer.clear(pkg)
                 fixer.protect(pkg)
 
-        fixer.install_protect()  # type: ignore
         try:
             fixer.resolve()
         except SystemError as exc:
@@ -1006,7 +1003,7 @@ class PackageManager(object):
         :param etraceback: Exception traceback.
         """
         message = '%s %s' % (_('Could not initialize package manager.'), '\n'.join(self._get_error_message(exc)))
-        six.reraise(etype, etype(message), etraceback)
+        raise etype(message).with_traceback(etraceback)
 
     def _get_error_message(self, exc):
         # type: (BaseException) -> List[str]
